﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace BSF_Utilities.Helpers
{
    /// <summary>
    /// Holds an array of controls and whether or not the controls should 
    /// have a constrained aspect ratio
    /// </summary>
    class ControlAspectLocker
    {
        private List<LockedControl> _lockedControls = new List<LockedControl>();

        /// <summary>
        /// Accept a control collection as this is what this.Controls yeilds
        /// </summary>
        /// <param name="controls"></param>
        public ControlAspectLocker(System.Windows.Forms.Control.ControlCollection controls)
        {
            // Add the controls to the locked list
            foreach (Control ctrl in controls)
            {
                _lockedControls.Add(new LockedControl(ctrl));
            }
        }

        /// <summary>
        /// Locks the aspect ratio by setting a value to represent the constraint ratio.
        /// Also set lockAspectRatio for the resize event
        /// </summary>
        public void LockAllControls()
        {
            foreach (LockedControl lCntrl in _lockedControls)
            {
                lCntrl.LockAspectRatio = true;
            }
        }

        /// <summary>
        /// Unlocks the aspect ratio so that it can be resized in a free form fashion
        /// </summary>
        public void UnlockAllControls()
        {
            foreach (LockedControl lCntrl in _lockedControls)
            {
                lCntrl.LockAspectRatio = false;
            }
        }

        /// <summary>
        /// Sets all locked controls to have a fill like anchor. Just a helper to
        /// save time as well as the opposite method.
        /// </summary>
        public void FullAnchorControls()
        {
            foreach (LockedControl lCntrl in _lockedControls)
            {
                lCntrl.Control.Anchor = AnchorStyles.Bottom | AnchorStyles.Left
                    | AnchorStyles.Right | AnchorStyles.Top;
            }
        }

        /// <summary>
        /// Sets all controls to not anchor, indirectly disabling the sizing constrain
        /// </summary>
        public void UnAnchorControls()
        {
            foreach (LockedControl lCntrl in _lockedControls)
            {
                lCntrl.Control.Anchor = AnchorStyles.None;
            }
        }
    }

    /// <summary>
    /// Accossiates the controls to be locked with their own lockstates
    /// </summary>
    class LockedControl
    {
        private Control _control;
        private double _aspectConstraint;
        private bool _lockAspectRatio;

        public LockedControl(Control control)
        {
            _control = control;
            _control.Resize +=new EventHandler(_control_Resize);
        }

        private void _control_Resize(object sender, EventArgs e)
        {
            if (_lockAspectRatio)
            {
                Control control = (Control)sender;
                control.Height = (int)((double)control.Width * _aspectConstraint + 0.5);
            }
        }

        public Control Control
        {
            get { return _control; }
        }

        /// <summary>
        /// Gets or sets whether or not to lock the aspect ratio
        /// </summary>
        public bool LockAspectRatio
        {
            get { return _lockAspectRatio; }
            set 
            {
                _aspectConstraint = (double)_control.Height / (double)_control.Width;
                _lockAspectRatio = value;
            }
        }
    }
}
