﻿using System;
using System.Text;
using System.Windows.Forms;
using System.Drawing;

namespace BSF_Utilities.Helpers
{
    /// <summary>
    /// This class is built to organize controls into a parent
    /// The controls must be same size
    /// </summary>
    static class ControlFlower
    {
        /// <summary>
        /// Adds and organises controls onto a control
        /// </summary>
        /// <param name="control">The control to lay out controls on</param>
        /// <param name="children">The controls to add to the control</param>
        static public void BeginLayout(Control control, params Control[] children)
        {
            byte column = 0;
            int totalWidth = 0;
            byte row = 0;
            const byte spacing = 10;

            control.Controls.Clear();

            foreach (Control c in children)
            {
                control.Controls.Add(c);

                int xPos = totalWidth = spacing + ((c.Width + spacing) * column);
                int yPos = spacing + (spacing + c.Height) * row;
                c.Location = new Point(xPos, yPos);

                column++;

                if (totalWidth + c.Width >= control.Width)
                {
                    column = 0;
                    row++;

                    totalWidth = spacing;

                    c.Location = new Point(spacing, spacing + ((spacing + c.Height) * row));
                    column++;
                }
            }
        }

        /// <summary>
        /// Adds and organises controls onto a control
        /// </summary>
        /// <param name="control">The control to lay out controls on</param>
        /// <param name="children">The controls to add to the control</param>
        /// <param name="progressbar">The progress bar to show layout progress</param>
        static public void BeginLayout(Control control, ProgressBar progressbar, Control[] children)
        {
            byte column = 0;
            int totalWidth = 0;
            byte row = 0;
            byte spacing = 10;

            progressbar.Maximum = children.Length;
            control.SuspendLayout();

            control.Controls.Clear();

            foreach (Control c in children)
            {
                control.Controls.Add(c);
                progressbar.Value++;

                int xPos = totalWidth = spacing + ((c.Width + spacing) * column);
                int yPos = spacing + ((spacing + c.Height) * row);
                c.Location = new Point(xPos, yPos);

                column++;

                if (totalWidth + c.Width >= control.Width)
                {
                    column = 0;
                    row++;
                    xPos = totalWidth = spacing + ((spacing + c.Width) * column);
                    yPos = spacing + ((spacing + c.Height) * row);
                    c.Location = new Point(xPos, yPos);
                    column++;
                }
            }
            control.ResumeLayout();
            control.Invalidate();
        }

        /// <summary>
        /// Adds and organises controls onto a control
        /// </summary>
        /// <param name="control">The control to lay out controls on</param>
        /// <param name="children">The controls to add to the control</param>
        /// <param name="spacing">The space between, each control. (pixel margin / 2)</param>
        static public void BeginLayout(Control control, byte spacing, Control[] children)
        {
            byte column = 0;
            int totalWidth = 0;
            byte row = 0;

            control.SuspendLayout();

            control.Controls.Clear();

            foreach (Control c in children)
            {
                control.Controls.Add(c);

                c.Location =
                new Point(totalWidth = spacing + ((c.Width + spacing) * column),
                    spacing + ((spacing + c.Height) * row));
                column++;

                if (totalWidth + c.Width >= control.Width)
                {
                    column = 0;
                    row++;
                    c.Location =
                    new Point(totalWidth = spacing + ((spacing + c.Width) * column),
                        spacing + ((spacing + c.Height) * row));
                    column++;
                }
            }
            control.ResumeLayout();
            control.Invalidate();
        }

        /// <summary>
        /// Adds and organises controls onto a control
        /// </summary>
        /// <param name="control">The control to lay out controls on</param>
        /// <param name="children">The controls to add to the control</param>
        /// <param name="progressbar">The progress bar to show layout progress</param>
        /// <param name="spacing">The space between, each control. (pixel margin / 2)</param>
        static public void BeginLayout(Control control, ProgressBar progressbar, byte spacing, Control[] children)
        {
            byte column = 0;
            int totalWidth = 0;
            byte row = 0;

            progressbar.Maximum = children.Length;
            control.SuspendLayout();

            control.Controls.Clear();

            foreach (Control c in children)
            {
                control.Controls.Add(c);
                progressbar.Value++;

                int xPos = totalWidth = spacing + ((c.Width + spacing) * column);
                int yPos = spacing + ((spacing + c.Height) * row);
                c.Location = new Point(xPos, yPos);

                column++;

                if (totalWidth + c.Width >= control.Width)
                {
                    column = 0;
                    row++;

                    xPos = totalWidth = spacing + ((spacing + c.Width) * column);
                    yPos = spacing + ((spacing + c.Height) * row);
                    c.Location = new Point(xPos, yPos);

                    column++;
                }
            }
            control.ResumeLayout();
            control.Invalidate();
        }
    }
}
