﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Drawing;
using System.IO;
using System.Collections.Specialized;
using System.Globalization;

namespace BSF_Utilities.Helpers
{
    /// <summary>
    /// Assume the less specific overloads are error boxes
    /// </summary>
    public static class ExtensionMethods
    {
        public static bool IsOdd(this int number)
        {
            return ((number & 1).Equals(0));
        }

        public static StringCollection Reverse(this StringCollection SC)
        {
            StringCollection temp = new StringCollection();

            for (int i = SC.Count - 1; i >= 0; i--)
            {
                temp.Add(SC[i]);
            }

            return temp;
        }

        public static string CapitalizeFirstLetter(this string text)
        {
            string firstLetter = text[0].ToString();
            firstLetter = firstLetter.ToUpper(CultureInfo.CurrentCulture);
            text = text.Remove(0, 1);
            text = text.Insert(0, firstLetter);
            return text;
        }

        public static string GetBasicInfo(this Font font)
        {
            return font.FontFamily.Name + " " + font.Size.ToString();
        }

        public static bool IsFileLarge(this FileInfo info)
        {
            // any thing over 120000 bytes will be considered a large document
            const int SIZE_THRESHOLD = 120000;

            if (!info.Exists)
            {
                return false;
            }
            else
            {
                return (info.Length > SIZE_THRESHOLD);
            }
        }

        public static void DockLeft(this Form form)
        {
            form.WindowState = FormWindowState.Normal;
            int width = Screen.PrimaryScreen.WorkingArea.Width / 2;
            int height = Screen.PrimaryScreen.WorkingArea.Height;
            form.Size = new Size(width, height);
            form.Location = Screen.PrimaryScreen.Bounds.Location;
        }

        public static void DockBottom(this Form form)
        {
            form.WindowState = FormWindowState.Normal;
            form.Width = Screen.PrimaryScreen.WorkingArea.Width;
            form.Height = Screen.PrimaryScreen.WorkingArea.Height / 2;

            int xPos = Screen.PrimaryScreen.WorkingArea.X;
            int workAreaHeight = Screen.PrimaryScreen.WorkingArea.Height;
            form.Location = new Point(xPos, workAreaHeight / 2);
        }

        public static void DockTop(this Form form)
        {
            form.WindowState = FormWindowState.Normal;
            form.Width = Screen.PrimaryScreen.WorkingArea.Width;
            form.Height = Screen.PrimaryScreen.WorkingArea.Height / 2;
            form.Location = Screen.PrimaryScreen.WorkingArea.Location;
        }

        public static void DockRight(this Form form)
        {
            form.WindowState = FormWindowState.Normal;
            int width = Screen.PrimaryScreen.WorkingArea.Width / 2;
            int height = Screen.PrimaryScreen.WorkingArea.Height;
            form.Size = new Size(width, height);
            int xPos = SystemInformation.PrimaryMonitorSize.Width - form.Width;
            int yPos = Screen.PrimaryScreen.WorkingArea.Y / 2;
            form.Location = new Point(xPos, yPos);
        }

        /// <summary>
        /// Gets the bit value as a character, bit value being 1 or 0
        /// </summary>
        public static char ToBitChar(this bool boolean)
        {
            if (boolean) return '1';
            else return '0';
        }

        /// <summary>
        /// Converts the char to a boolean. 1 returns true,
        /// everything else returns false
        /// </summary>
        public static bool ToBoolean(this char c)
        {
            return (c.Equals('1'));
        }
    }
}
