﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Runtime.InteropServices;

namespace BSF_Utilities
{
    class KernelTimer
    {
        [DllImport("Kernel32.dll")]
        private static extern long GetTickCount();
        private long _startTimeElapsed;

        public KernelTimer()
        {
            Reset();
        }

        public void Reset()
        {
            _startTimeElapsed = GetTickCount();
        }

        /// <summary>
        /// Gets the time elapsed in miliseconds
        /// </summary>
        public long ElapsedMiliSeconds
        {
            get
            {
                return (GetTickCount() - _startTimeElapsed) / 10000000;
            }
        }

        /// <summary>
        /// Gets the time elapsed in seconds
        /// </summary>
        public long ElapsedSeconds
        {
            get { return (GetTickCount() - _startTimeElapsed) / 10000000000; }
        }

        /// <summary>
        /// Gets the elapsed time since the last reset
        /// </summary>
        public long ElapsedTime
        {
            get
            {
                return GetTickCount() - _startTimeElapsed;
            }
        }

        public override string ToString()
        {
            string result = "Elapsed Time = {0}, ";
            result += "Elapsed Miliseconds = {1}, ";
            result += "Elapsed Seconds = {2}";

            return String.Format(result, this.ElapsedTime,
                this.ElapsedMiliSeconds, this.ElapsedSeconds);
        }
    }
}
