﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using IWshRuntimeLibrary;
using System.Windows.Forms;
using System.Linq;
using System.Drawing;

namespace BSF_Utilities
{
    static class MiscFunctions
    {
        public static void CreateShortcut(string saveLocation, string targetPath, string description)
        {
            WshShellClass wshShell = new WshShellClass();
            object tempObj = wshShell.CreateShortcut(saveLocation);
            IWshShortcut shortcut = (IWshShortcut)tempObj;
            shortcut.TargetPath = targetPath;
            shortcut.Description = description;
            shortcut.Save();
        }

        public static Rectangle GetScreenRectsCombined()
        {
            Rectangle rect = new Rectangle();

            foreach (Screen screen in Screen.AllScreens)
            {
                rect = Rectangle.Union(rect, screen.Bounds);
            }

            return rect;
        }

        public static Stack<T> ReverseStack<T>(Stack<T> stringStack) where T : class
        {
            Stack<T> tempStack = stringStack;
            Stack<T> resultStack = new Stack<T>();

            while (tempStack.Count > 0)
            {
                resultStack.Push(tempStack.Pop());
            }

            return resultStack;
        }

        /// <summary>
        /// Deletes all files in a specified directory
        /// </summary>
        static public void ClearDirectory(string directory)
        {
            try
            {
                DirectoryInfo dirInfo = new DirectoryInfo(directory);
                FileInfo[] fileInfo = dirInfo.GetFiles();

                foreach (FileInfo file in fileInfo)
                {
                    file.Delete();
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, Application.ProductName,
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        static public void WalkDirectoryTree(DirectoryInfo root)
        {
            FileInfo[] files = null;

            // First, process all the files directly under this folder
            try
            {
                files = root.GetFiles();
            }
            // This is thrown if even one of the files requires permissions greater
            // than the application provides.
            catch {}

            if (files != null)
            {
                foreach (FileInfo fi in files)
                {
                    // In this example, we only access the existing FileInfo object. If we
                    // want to open, delete or modify the file, then
                    // a try-catch block is required here to handle the case
                    // where the file has been deleted since the call to TraverseTree().
                    Console.WriteLine(fi.FullName);
                }

                // Now find all the subdirectories under this directory.
                DirectoryInfo[] subDirs = root.GetDirectories();

                foreach (DirectoryInfo dirInfo in subDirs)
                {
                    // Resursive call for each subdirectory.
                    WalkDirectoryTree(dirInfo);
                }
            }
        }
    }
}
