﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using System.Windows.Forms;
using System.Drawing.Imaging;
using System.ComponentModel;
using System.IO;

namespace BSF_Utilities
{
    static class ScreenShooter
    {
        /// <summary>
        /// Captures the screen of the primary monitor and returns a bitmap
        /// of the specified pixel format
        /// </summary>
        public static Bitmap CaptureFullScreen(PixelFormat format)
        {
            int height = Screen.PrimaryScreen.Bounds.Height;
            int width = Screen.PrimaryScreen.Bounds.Width;
            Bitmap screenshot = new Bitmap(width, height, format);

            Graphics GFX = Graphics.FromImage(screenshot);
            GFX.CopyFromScreen(Point.Empty, Point.Empty, Screen.PrimaryScreen.Bounds.Size);
            GFX.Dispose();

            return screenshot;
        }

        /// <summary>
        /// Captures the screen of the primary monitor
        /// </summary>
        public static Bitmap CaptureFullScreen()
        {
            int height = Screen.PrimaryScreen.Bounds.Height;
            int width = Screen.PrimaryScreen.Bounds.Width;
            Bitmap screenshot = new Bitmap(width, height, PixelFormat.Format32bppRgb);

            Graphics GFX = Graphics.FromImage(screenshot);
            GFX.CopyFromScreen(Point.Empty, Point.Empty, Screen.PrimaryScreen.Bounds.Size);
            GFX.Dispose();

            return screenshot;
        }

        /// <summary>
        /// Captures the entire area of a specified screen
        /// </summary>
        public static Bitmap CaptureFullScreen(int screenIndex)
        {
            int height = Screen.AllScreens[screenIndex].Bounds.Height;
            int width = Screen.AllScreens[screenIndex].Bounds.Width;
            Bitmap screenshot = new Bitmap(width, height, PixelFormat.Format32bppRgb);

            Graphics GFX = Graphics.FromImage(screenshot);
            GFX.CopyFromScreen(Point.Empty, Point.Empty, Screen.AllScreens[screenIndex].Bounds.Size);
            GFX.Dispose();

            return screenshot;
        }

        #region Region Capture
        public static Bitmap CaptureRegion(Rectangle rect)
        {
            Bitmap screenshot = new Bitmap(rect.Width, rect.Height, PixelFormat.Format32bppRgb);

            Graphics GFX = Graphics.FromImage(screenshot);
            GFX.CopyFromScreen(rect.Location, Point.Empty, rect.Size);
            GFX.Dispose();

            return screenshot;
        }

        public static Bitmap CaptureRegion(Rectangle rect, PixelFormat format)
        {
            Bitmap screenshot = new Bitmap(rect.Width, rect.Height, format);

            Graphics GFX = Graphics.FromImage(screenshot);
            GFX.CopyFromScreen(rect.Location, Point.Empty, rect.Size);
            GFX.Dispose();

            return screenshot;
        }

        public static Bitmap CaptureRegion(Point pos, Size size, PixelFormat format)
        {
            Bitmap screenshot = new Bitmap(size.Width, size.Height, format);

            Graphics GFX = Graphics.FromImage(screenshot);
            GFX.CopyFromScreen(pos, Point.Empty, size);
            GFX.Dispose();

            return screenshot;
        }

        public static Bitmap CaptureRegion(Point pos, Size size)
        {
            Bitmap screenshot = new Bitmap(size.Width, size.Height, PixelFormat.Format32bppRgb);

            Graphics GFX = Graphics.FromImage(screenshot);
            GFX.CopyFromScreen(pos, Point.Empty, size);
            GFX.Dispose();

            return screenshot;
        }
        #endregion
    }
}
