﻿using System;
using System.Collections.Generic;
using System.Text;

namespace BSF_Code_Library.Helpers
{
    static class StringOps
    {
        public static string TrimNumbersFromStart(this string s)
        {
            while (char.IsNumber(s[0]))
            {
                s = s.Remove(0, 1);
            }

            return s;
        }

        /// <summary>
        /// Expands the body string at the start and end with specified text
        /// </summary>
        public static string ExpandString(this string body, string leftInsert, string rightInsert)
        {
            body = body.Insert(0, leftInsert);
            body = body.Insert(body.Length, rightInsert);

            return body;
        }

        /// <summary>
        /// Gets the parent directory of the directory sent in (Do not include file IDs)
        /// </summary>
        private static string GetParentDirectory(string path)
        {
            string[] strArray = path.Split('\\');
            List<string> stringList = new List<string>(strArray);
            stringList.RemoveAt(stringList.Count - 1);

            string result = string.Empty;

            foreach (string s in stringList)
            {
                result += s + "\\";
            }

            return result;
        }

        /// <summary>
        /// Trims a certain amout of characters off the start and end of the string
        /// </summary>
        static public string TrimStringApex(this string input, int amountToTrim)
        {
            if (input.Length - amountToTrim * 2 >= 0)
            {
                input = input.Remove(0, amountToTrim);
                input = input.Remove(input.Length - amountToTrim, amountToTrim);
            }
            else
            {
                input = string.Empty;
            }

            return input;
        }

        /// <summary>
        /// Same thing as contains, just with multiple search instances
        /// </summary>
        static public bool HasStringInstance(string lookIn, string[] instances, bool matchCase)
        {
            foreach (string s in instances)
            {
                lookIn = (matchCase) ? lookIn : lookIn.ToLower();
                if (lookIn.Contains(s)) return true;
            }

            return false;
        }

        /// <summary>
        /// Removes all letters from the passed in string
        /// </summary>
        public static string IsolateNumbers(this string s)
        {
            for (int i = 0; i < s.Length; i++)
            {
                while (i < s.Length && i >= 0 && !char.IsNumber(s[i]))
                {
                    s = s.Remove(i, 1);
                }
            }

            return s;
        }

        /// <summary>
        /// Removes all numbers from the passed in string
        /// </summary>
        public static string IsolateLetters(this string s)
        {
            for (int i = 0; i < s.Length; i++)
            {
                while (i < s.Length && i >= 0 && !char.IsLetter(s[i]))
                {
                    s = s.Remove(i, 1);
                }
            }

            return s;
        }

        /// <summary>
        /// Removes all non number and letter characters from the passed in string
        /// </summary>
        public static string IsolateAlphanumerics(this string s)
        {
            for (int i = 0; i < s.Length; i++)
            {
                while (i < s.Length && i >= 0 && !char.IsLetter(s[i]) && !char.IsNumber(s[i]))
                {
                    s = s.Remove(i, 1);
                }
            }

            return s;
        }

        /// <summary>
        /// Determines whether or not the string has an instance of paired curly braces
        /// </summary>
        public static bool StringHasParenthesis(this string s)
        {
            bool hasOpening = false;
            bool hasClosing = false;

            foreach (char c in s)
            {
                if (c == '(') hasOpening = true;

                // Make sure closing string is after opening
                if (hasOpening)
                {
                    if (c == ')') hasClosing = true;
                }
            }

            return (hasOpening && hasClosing);
        }

        /// <summary>
        /// Finds the first occurence of content between curly braces
        /// and returns the contents with or without the braces
        /// </summary>
        public static string IsolateParenthesis(this string s, bool includeBraces)
        {
            int openIndex = -1;
            int endIndex = -1;

            for (int i = 0; i < s.Length; i++)
            {
                if (s[i] == '(') openIndex = i;
                else if (s[i] == ')') endIndex = i;
            }

            if (openIndex > -1 && endIndex > -1 && openIndex < endIndex)
            {
                if (includeBraces)
                {
                    return s.Substring(openIndex, endIndex - openIndex + 1);
                }
                else
                {
                    return s.Substring(openIndex + 1, endIndex - openIndex);
                }
            }
            else
            {
                return s;
            }
        }

        /// <summary>
        /// If the string array contains the specified instance, the mothod returns true
        /// </summary>
        public static bool ArrayContains(string[] array, string instance)
        {
            foreach (string s in array)
            {
                if (s.Contains(instance))
                {
                    return true;
                }
            }

            return false;
        }

        /// <summary>
        /// Gets the number count for the specified string
        /// </summary>
        public static int NumberCount(this string s)
        {
            int count = 0;

            foreach (char c in s)
            {
                if (char.IsNumber(c))
                {
                    count++;
                }
            }

            return count;
        }

        /// <summary>
        /// Gets the aletter count for the specified string
        /// </summary>
        public static int LetterCount(this string s)
        {
            int count = 0;

            foreach (char c in s)
            {
                if (char.IsLetter(c))
                {
                    count++;
                }
            }

            return count;
        }

        /// <summary>
        /// If the string consists of all numbers, method returns true, other wise it returns false
        /// </summary>
        public static bool IsAllNumbers(this string s)
        {
            foreach (char c in s)
            {
                if (!char.IsNumber(c))
                {
                    return false;
                }
            }

            return true;
        }

        /// <summary>
        /// If the string consists of all letters, method returns true, other wise it returns false
        /// </summary>
        public static bool IsAllLetters(this string s)
        {
            foreach (char c in s)
            {
                if (!char.IsLetter(c))
                {
                    return false;
                }
            }

            return true;
        }
    }
}
