﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;

namespace BSF_Code_Library.Helpers
{
    /// <summary>
    /// Broken sorry, reconstruct for every use
    /// </summary>
    struct UnitVector
    {
        private double _rise, _run;
        private PointF _startPoint;

        public UnitVector(PointF startPoint, int length, double angleInDegrees)
        {
            _startPoint = startPoint;
            _rise = _run = length;
            this.Radian = DegreeToRadian(angleInDegrees);
        }

        public static double DegreeToRadian(double angle)
        {
            return Math.PI * angle / 180.0;
        }

        public PointF EndPoint
        {
            get
            {
                float xPos = (float)(_startPoint.Y + _rise);
                float yPos = (float)(_startPoint.X + _run);
                return new PointF(yPos, xPos);
            }
        }

        public PointF StartPoint
        {
            get { return _startPoint; }
        }

        public double Radian
        {
            get
            {
                double radian = Math.Atan2(_rise, _run);

                if (radian < 0)
                {
                    radian += Math.PI * 2;
                }

                return radian;
            }
            set
            {
                if (value > Math.PI * 2) value = Math.PI * 2;
                if (value < 0) value = 0;

                _rise = Math.Sin(value) * _rise;
                _run = Math.Cos(value) * _run;
            }
        }
    }
}
